# eric7.Project.MakePropertiesDialog

Module implementing a dialog to enter the properties for 'make'.

### Global Attributes

None

### Classes

MakePropertiesDialog | Class implementing a dialog to enter the properties for 'make'.

### Functions

None

## MakePropertiesDialog

Class implementing a dialog to enter the properties for 'make'.

### Derived from

QDialog, Ui_MakePropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

MakePropertiesDialog | Constructor
__updateOkButton | Private slot to update the enabled state of the OK button.
initDialog | Public method to initialize the dialog's data.
storeData | Public method to store the entered/modified data.

### Static Methods

None

#### MakePropertiesDialog (Constructor)

MakePropertiesDialog(project, new, parent=None)

Constructor

project (Project)
  reference to the project object
new (bool)
  flag indicating the generation of a new project
parent (QWidget)
  reference to the parent widget of this dialog

#### MakePropertiesDialog.__updateOkButton

__updateOkButton()

Private slot to update the enabled state of the OK button.

#### MakePropertiesDialog.initDialog

initDialog()

Public method to initialize the dialog's data.

#### MakePropertiesDialog.storeData

storeData()

Public method to store the entered/modified data.

Up